@@ -1,5 +1,3 @@
-/* $Id: procuid.c 2422 2005-12-12 09:38:15Z jamesh $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -46,7 +44,7 @@ static const unsigned long _glibtop_sysdeps_proc_uid =
 /* Init function. */
 
 void
-glibtop_init_proc_uid_p (glibtop *server)
+_glibtop_init_proc_uid_p (glibtop *server)
 {
 	server->sysdeps.proc_uid = _glibtop_sysdeps_proc_uid;
 }
